@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2022 Giovanni A. Zuliani | Monocasual Laboratories
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,18 +24,22 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef G_INIT_H
 #define G_INIT_H
 
+namespace giada::m::init
+{
+/* tests
+Performs tests, if requested. Returns -1 if no tests are available or the 
+`--run-tests` has not been passed in. */
 
-void init_prepareParser();
-void init_startGUI(int argc, char **argv);
-void init_prepareKernelAudio();
-void init_prepareKernelMIDI();
-void init_prepareMidiMap();
-void init_startKernelAudio();
-void init_shutdown();
+int tests(int argc, char** argv);
 
+void printBuildInfo();
+void startup(int argc, char** argv);
+int  run();
+void closeMainWindow();
+void shutdown();
+} // namespace giada::m::init
 
-#endif
+#endif
\ No newline at end of file
