@@ -1,11 +1,5 @@
-#ifndef __JUCE_APPCONFIG_H__
-#define __JUCE_APPCONFIG_H__
-
-
-#ifdef _WIN32
-  #include <sys/types.h>
-  #include <sys/time.h>
-#endif
+#ifndef JUCE_APPCONFIG_H
+#define JUCE_APPCONFIG_H
 
 
 #include "juce/modules/juce_audio_basics/juce_audio_basics.h"
