@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2022 Giovanni A. Zuliani | Monocasual Laboratories
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,40 +24,17 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef G_GLUE_RECORDER_H
 #define G_GLUE_RECORDER_H
 
+#include "core/types.h"
 
-#include <vector>
-#include "../core/recorder.h"
-
-
-class geChannel;
-
-
-namespace giada {
-namespace c     {
-namespace recorder 
+namespace giada::c::recorder
 {
-void clearAllActions(geChannel *gch);
-void clearMuteActions(geChannel *gch);
-void clearVolumeActions(geChannel *gch);
-void clearStartStopActions(geChannel *gch);
-
-/* recordMidiAction
-Records a new MIDI action at frame_a. If frame_b == 0, uses the default action
-size. This function is designed for the Piano Roll (not for live recording). */
-
-void recordMidiAction(int chan, int note, int frame_a, int frame_b=0);
-
-/* getMidiActions
-Returns a list of Composite actions, ready to be displayed in a MIDI note
-editor as pairs of NoteOn+NoteOff. */
-
-std::vector<giada::m::recorder::Composite> getMidiActions(int channel, 
-	int frameLimit);
-
-}}} // giada::c::recorder::
+void clearAllActions(ID channelId);
+void clearVolumeActions(ID channelId);
+void clearStartStopActions(ID channelId);
+void updateChannel(ID channelId, bool updateActionEditor);
+} // namespace giada::c::recorder
 
 #endif
