@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2022 Giovanni A. Zuliani | Monocasual Laboratories
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,16 +24,15 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef G_GLUE_STORAGE_H
 #define G_GLUE_STORAGE_H
 
-
-void glue_loadPatch  (void *data);
-void glue_savePatch  (void *data);
-void glue_saveProject(void *data);
-void glue_saveSample (void *data);
-void glue_loadSample (void *data);
-
+namespace giada::c::storage
+{
+void loadProject(void* data);
+void saveProject(void* data);
+void saveSample(void* data);
+void loadSample(void* data);
+} // namespace giada::c::storage
 
 #endif
