@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2022 Giovanni A. Zuliani | Monocasual Laboratories
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,36 +24,26 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GD_BEATSINPUT_H
 #define GD_BEATSINPUT_H
 
-
 #include "window.h"
 
-
 class geInput;
+
+namespace giada::v
+{
 class geButton;
-class geCheck;
-
-
 class gdBeatsInput : public gdWindow
 {
-private:
-
-	static void cb_update(Fl_Widget* w, void* p);
-	void cb_update();
-
-	geInput* beats;
-	geInput* bars;
-	geButton* ok;
-	geCheck* resizeRec;
-
 public:
+	gdBeatsInput(int beats, int bars);
 
-	gdBeatsInput();
-	~gdBeatsInput();
+private:
+	geInput*  m_beats;
+	geInput*  m_bars;
+	geButton* m_ok;
 };
-
+} // namespace giada::v
 
 #endif
