@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2022 Giovanni A. Zuliani | Monocasual Laboratories
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,75 +24,69 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GD_BROWSER_BASE_H
 #define GD_BROWSER_BASE_H
 
-
-#include "../window.h"
-
+#include "core/conf.h"
+#include "core/types.h"
+#include "gui/dialogs/window.h"
+#include <functional>
+#include <string>
 
 class Fl_Group;
-class Channel;
 class geCheck;
-class geBrowser;
-class geButton;
 class geInput;
-class geProgress;
 
+namespace giada::m
+{
+class Channel;
+}
 
+namespace giada::v
+{
+class geButton;
+class geFileBrowser;
 class gdBrowserBase : public gdWindow
 {
-protected:
-
-	Channel* channel;
-
-	Fl_Group* groupTop;
-	geCheck* hiddenFiles;
-	geBrowser* browser;
-	geButton* ok;
-	geButton* cancel;
-	geInput* where;
-	geButton* updir;
-	geProgress* status;
-
-	static void cb_up(Fl_Widget* v, void* p);
-	static void cb_close(Fl_Widget* w, void* p);
-	static void cb_toggleHiddenFiles(Fl_Widget* w, void* p);
-	void cb_up();
-	void cb_close();
-	void cb_toggleHiddenFiles();
-
-	/* Callback
-	 * Fired when the save/load button is pressed. */
-
-	void (*callback)(void*);
-
-	gdBrowserBase(int x, int y, int w, int h, const std::string& title,
-		const std::string& path, void (*callback)(void*));
-
 public:
-
 	~gdBrowserBase();
 
 	/* getSelectedItem
-	 * Return the full path of the selected file. */
+	Returns the full path of the selected file. */
 
 	std::string getSelectedItem() const;
 
 	std::string getCurrentPath() const;
-	Channel* getChannel() const;
-	void fireCallback() const;
-	
-	/* setStatusBar
-	 * Increment status bar for progress tracking. */
+	ID          getChannelId() const;
+	void        fireCallback() const;
 
-	void setStatusBar(float v);
+protected:
+	gdBrowserBase(const std::string& title, const std::string& path,
+	    std::function<void(void*)> f, ID channelId, m::Conf::Data&);
 
-	void showStatusBar();
-	void hideStatusBar();
+	static void cb_up(Fl_Widget* /*w*/, void* p);
+	static void cb_close(Fl_Widget* /*w*/, void* p);
+	static void cb_toggleHiddenFiles(Fl_Widget* /*w*/, void* p);
+	void        cb_up();
+	void        cb_close();
+	void        cb_toggleHiddenFiles();
 
+	/* m_callback
+	Fired when the save/load button is pressed. */
+
+	std::function<void(void*)> m_callback;
+
+	m::Conf::Data& m_conf;
+	ID             m_channelId;
+
+	Fl_Group*      groupTop;
+	geCheck*       hiddenFiles;
+	geFileBrowser* browser;
+	geButton*      ok;
+	geButton*      cancel;
+	geInput*       where;
+	geButton*      updir;
 };
-
+} // namespace giada::v
 
 #endif
