@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2022 Giovanni A. Zuliani | Monocasual Laboratories
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,64 +24,57 @@
  *
  * -------------------------------------------------------------------------- */
 
+#include "gui/dialogs/browser/browserLoad.h"
+#include "gui/elems/basics/button.h"
+#include "gui/elems/basics/input.h"
+#include "gui/elems/fileBrowser.h"
+#include "gui/ui.h"
+#include "utils/fs.h"
 
-#include "../../../utils/fs.h"
-#include "../../elems/browser.h"
-#include "../../elems/basics/button.h"
-#include "../../elems/basics/input.h"
-#include "browserLoad.h"
+extern giada::v::Ui g_ui;
 
-
-using std::string;
-
-
-gdBrowserLoad::gdBrowserLoad(int x, int y, int w, int h, const string& title,
-		const string& path, void (*cb)(void*), Channel* ch)
-	:	gdBrowserBase(x, y, w, h, title, path, cb)
+namespace giada::v
 {
-	channel = ch;
+gdBrowserLoad::gdBrowserLoad(const std::string& title, const std::string& path,
+    std::function<void(void*)> cb, ID channelId, m::Conf::Data& conf)
+: gdBrowserBase(title, path, cb, channelId, conf)
+{
+	where->size(groupTop->w() - updir->w() - 8, 20);
 
-	where->size(groupTop->w()-updir->w()-8, 20);
+	browser->callback(cb_down, (void*)this);
 
-	browser->callback(cb_down, (void*) this);
-
-	ok->label("Load");
-	ok->callback(cb_load, (void*) this);
+	ok->label(g_ui.langMapper.get(LangMap::COMMON_LOAD));
+	ok->callback(cb_load, (void*)this);
 	ok->shortcut(FL_ENTER);
 
 	/* On OS X the 'where' input doesn't get resized properly on startup. Let's 
 	force it. */
-	
+
 	where->redraw();
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
-void gdBrowserLoad::cb_load(Fl_Widget* v, void* p) { ((gdBrowserLoad*)p)->cb_load(); }
-void gdBrowserLoad::cb_down(Fl_Widget* v, void* p) { ((gdBrowserLoad*)p)->cb_down(); }
-
+void gdBrowserLoad::cb_load(Fl_Widget* /*v*/, void* p) { ((gdBrowserLoad*)p)->cb_load(); }
+void gdBrowserLoad::cb_down(Fl_Widget* /*v*/, void* p) { ((gdBrowserLoad*)p)->cb_down(); }
 
 /* -------------------------------------------------------------------------- */
 
-
 void gdBrowserLoad::cb_load()
 {
-	callback((void*) this);
+	fireCallback();
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 void gdBrowserLoad::cb_down()
 {
-	string path = browser->getSelectedItem();
+	std::string path = browser->getSelectedItem();
 
-	if (path.empty() || !gu_isDir(path)) // when click on an empty area or not a dir
+	if (path.empty() || !u::fs::isDir(path)) // when click on an empty area or not a dir
 		return;
 
 	browser->loadDir(path);
 	where->value(browser->getCurrentDir().c_str());
 }
+} // namespace giada::v
\ No newline at end of file
