@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2022 Giovanni A. Zuliani | Monocasual Laboratories
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,31 +24,31 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GD_BROWSER_LOAD_H
 #define GD_BROWSER_LOAD_H
 
-
 #include "browserBase.h"
+#include "core/conf.h"
 
-
+namespace giada::m
+{
 class Channel;
+}
 
-
+namespace giada::v
+{
 class gdBrowserLoad : public gdBrowserBase
 {
-private:
-
-	static void cb_load(Fl_Widget* w, void* p);
-	static void cb_down(Fl_Widget* v, void* p);
-	void cb_load();
-	void cb_down();
-
 public:
+	gdBrowserLoad(const std::string& title, const std::string& path,
+	    std::function<void(void*)> cb, ID channelId, m::Conf::Data&);
 
-	gdBrowserLoad(int x, int y, int w, int h, const std::string& title,
-			const std::string& path, void (*callback)(void*), Channel* ch);
+private:
+	static void cb_load(Fl_Widget* /*w*/, void* p);
+	static void cb_down(Fl_Widget* /*w*/, void* p);
+	void        cb_load();
+	void        cb_down();
 };
-
+} // namespace giada::v
 
 #endif
