@@ -2,11 +2,9 @@
  *
  * Giada - Your Hardcore Loopmachine
  *
- * midiInputMaster
- *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2017 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2022 Giovanni A. Zuliani | Monocasual Laboratories
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -26,20 +24,44 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GD_MIDI_INPUT_MASTER_H
 #define GD_MIDI_INPUT_MASTER_H
 
-
+#include "core/conf.h"
+#include "glue/io.h"
+#include "gui/elems/midiIO/midiLearnerPack.h"
 #include "midiInputBase.h"
 
+class geCheck;
+
+namespace giada::v
+{
+class geChoice;
+class geMasterLearnerPack : public geMidiLearnerPack
+{
+public:
+	geMasterLearnerPack(int x, int y);
+
+	void update(const c::io::Master_InputData&);
+};
+
+/* -------------------------------------------------------------------------- */
 
 class gdMidiInputMaster : public gdMidiInputBase
 {
 public:
+	gdMidiInputMaster(m::Conf::Data&);
 
-	gdMidiInputMaster();
+	void rebuild() override;
+
+private:
+	static void cb_enable(Fl_Widget* /*w*/, void* p);
+	void        cb_enable();
+
+	c::io::Master_InputData m_data;
+
+	geMasterLearnerPack* m_learners;
 };
-
+} // namespace giada::v
 
 #endif
