@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2017 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2022 Giovanni A. Zuliani | Monocasual Laboratories
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,91 +24,70 @@
  *
  * -------------------------------------------------------------------------- */
 
+#include "gui/dialogs/midiIO/midiOutputBase.h"
+#include "glue/io.h"
+#include "gui/elems/basics/check.h"
+#include "gui/elems/midiIO/midiLearner.h"
+#include "gui/ui.h"
 
-#include "../../../utils/log.h"
-#include "../../elems/midiLearner.h"
-#include "midiOutputBase.h"
+extern giada::v::Ui g_ui;
 
+namespace giada::v
+{
+geLightningLearnerPack::geLightningLearnerPack(int x, int y, ID channelId)
+: geMidiLearnerPack(x, y)
+{
+	setCallbacks(
+	    [channelId](int param) { c::io::channel_startMidiLearn(param, channelId); },
+	    [channelId](int param) { c::io::channel_clearMidiLearn(param, channelId); });
+	addMidiLearner(g_ui.langMapper.get(LangMap::MIDIOUTPUT_CHANNEL_LEARN_PLAYING), G_MIDI_OUT_L_PLAYING);
+	addMidiLearner(g_ui.langMapper.get(LangMap::MIDIOUTPUT_CHANNEL_LEARN_MUTE), G_MIDI_OUT_L_MUTE);
+	addMidiLearner(g_ui.langMapper.get(LangMap::MIDIOUTPUT_CHANNEL_LEARN_SOLO), G_MIDI_OUT_L_SOLO);
+}
 
-using namespace giada::m;
+/* -------------------------------------------------------------------------- */
 
+void geLightningLearnerPack::update(const c::io::Channel_OutputData& d)
+{
+	learners[0]->update(d.lightningPlaying);
+	learners[1]->update(d.lightningMute);
+	learners[2]->update(d.lightningSolo);
+	setEnabled(d.lightningEnabled);
+}
 
-gdMidiOutputBase::gdMidiOutputBase(int w, int h)
-	: gdWindow(w, h, "Midi Output Setup")
+/* -------------------------------------------------------------------------- */
+/* -------------------------------------------------------------------------- */
+/* -------------------------------------------------------------------------- */
+
+gdMidiOutputBase::gdMidiOutputBase(int w, int h, ID channelId)
+: gdWindow(w, h, g_ui.langMapper.get(LangMap::MIDIOUTPUT_CHANNEL_TITLE))
+, m_channelId(channelId)
 {
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
-void gdMidiOutputBase::stopMidiLearn(geMidiLearner *learner)
+gdMidiOutputBase::~gdMidiOutputBase()
 {
-	kernelMidi::stopMidiLearn();
-	learner->updateValue();
+	c::io::stopMidiLearn();
 }
 
+/* -------------------------------------------------------------------------- */
+
+void gdMidiOutputBase::cb_close(Fl_Widget* /*w*/, void* p) { ((gdMidiOutputBase*)p)->cb_close(); }
+void gdMidiOutputBase::cb_enableLightning(Fl_Widget* /*w*/, void* p) { ((gdMidiOutputBase*)p)->cb_enableLightning(); }
 
 /* -------------------------------------------------------------------------- */
 
-
-void gdMidiOutputBase::__cb_learn(uint32_t *param, uint32_t msg, geMidiLearner *l)
-{
-	*param = msg;
-	stopMidiLearn(l);
-	gu_log("[gdMidiGrabber] MIDI learn done - message=0x%X\n", msg);
-}
-
-
-/* -------------------------------------------------------------------------- */
-
-
-void gdMidiOutputBase::cb_learn(uint32_t msg, void *d)
-{
-	geMidiLearner::cbData_t *data = (geMidiLearner::cbData_t*) d;
-	gdMidiOutputBase  *window  = (gdMidiOutputBase*) data->window;
-	geMidiLearner *learner = data->learner;
-	uint32_t      *param   = learner->param;
-	window->__cb_learn(param, msg, learner);
-}
-
-
-/* -------------------------------------------------------------------------- */
-
-
-void gdMidiOutputBase::cb_close(Fl_Widget *w, void *p)  { ((gdMidiOutputBase*)p)->__cb_close(); }
-
-
-/* -------------------------------------------------------------------------- */
-
-
-void gdMidiOutputBase::__cb_close()
+void gdMidiOutputBase::cb_close()
 {
 	do_callback();
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
-void gdMidiOutputBase::cb_enableLightning(Fl_Widget *w, void *p)
+void gdMidiOutputBase::cb_enableLightning()
 {
-	((gdMidiOutputBase*)p)->__cb_enableLightning();
-}
-
-
-/* -------------------------------------------------------------------------- */
-
-
-void gdMidiOutputBase::__cb_enableLightning() {}
-
-
-/* -------------------------------------------------------------------------- */
-
-
-void gdMidiOutputBase::setTitle(int chanNum)
-{
-	char title[64];
-	sprintf(title, "MIDI Output Setup (channel %d)", chanNum);
-	copy_label(title);
+	c::io::channel_enableMidiLightning(m_channelId, m_enableLightning->value());
 }
+} // namespace giada::v
