@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2022 Giovanni A. Zuliani | Monocasual Laboratories
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,32 +24,23 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GD_MIDI_OUTPUT_SAMPLE_CH_H
 #define GD_MIDI_OUTPUT_SAMPLE_CH_H
 
-
 #include "midiOutputBase.h"
 
-
-class SampleChannel;
-
-
+namespace giada
+{
+namespace v
+{
 class gdMidiOutputSampleCh : public gdMidiOutputBase
 {
-private:
-
-	SampleChannel *ch;
-
-	/* __cb_close
-	override parent method, we need to do more stuff on close. */
-
-	static void cb_close  (Fl_Widget *w, void *p);
-	inline void __cb_close();
-
 public:
+	gdMidiOutputSampleCh(ID channelId);
 
-	gdMidiOutputSampleCh(SampleChannel *ch);
+	void rebuild() override;
 };
+} // namespace v
+} // namespace giada
 
 #endif
