@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2022 Giovanni A. Zuliani | Monocasual Laboratories
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,175 +24,160 @@
  *
  * -------------------------------------------------------------------------- */
 
-
-#include "../../utils/log.h"
 #include "window.h"
+#include "utils/log.h"
+#include <FL/Fl.H>
 
-
-void __cb_window_closer(Fl_Widget *v, void *p)
+namespace giada::v
 {
-  delete (Fl_Window*) p;
+gdWindow::gdWindow(int x, int y, int w, int h, const char* title, int id)
+: Fl_Double_Window(x, y, w, h, title)
+, id(id)
+, parent(nullptr)
+{
+	end();
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
-gdWindow::gdWindow(int x, int y, int w, int h, const char *title, int id)
-	: Fl_Double_Window(x, y, w, h, title), id(id), parent(nullptr)
+gdWindow::gdWindow(int w, int h, const char* title, int id)
+: Fl_Double_Window(w, h, title)
+, id(id)
+, parent(nullptr)
 {
+	end();
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
-gdWindow::gdWindow(int w, int h, const char *title, int id)
-	: Fl_Double_Window(w, h, title), id(id), parent(nullptr)
+gdWindow::gdWindow(geompp::Rect<int> r, const char* title, int id)
+: gdWindow(r.x, r.y, r.w, r.h, title, id)
 {
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
 gdWindow::~gdWindow()
 {
 	/* delete all subwindows in order to empty the stack */
 
-	for (unsigned i=0; i<subWindows.size(); i++)
-		delete subWindows.at(i);
+	for (unsigned j = 0; j < subWindows.size(); j++)
+		delete subWindows.at(j);
 	subWindows.clear();
 }
 
-
 /* -------------------------------------------------------------------------- */
 
 /* this is the default callback of each window, fired when the user closes
  * the window with the 'x'. Watch out: is the parent that calls delSubWIndow */
 
-void gdWindow::cb_closeChild(Fl_Widget *v, void *p)
+void gdWindow::cb_closeChild(Fl_Widget* w, void* /*p*/)
 {
-	gdWindow *child = (gdWindow*) v;
+	/* Disable default FLTK behavior where 'escape' closes the window. */
+	if (Fl::event() == FL_SHORTCUT && Fl::event_key() == FL_Escape)
+		return;
+
+	gdWindow* child = (gdWindow*)w;
 	if (child->getParent() != nullptr)
 		(child->getParent())->delSubWindow(child);
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
-void gdWindow::addSubWindow(gdWindow *w)
+void gdWindow::addSubWindow(gdWindow* w)
 {
-	/** TODO - useless: delete ---------------------------------------- */
-	for (unsigned i=0; i<subWindows.size(); i++)
-		if (w->getId() == subWindows.at(i)->getId()) {
-			//gu_log("[gdWindow] window %p (id=%d) exists, not added (and deleted)\n", (void*)w, w->getId());
-			delete w;
-			return;
-		}
-	/** --------------------------------------------------------------- */
-
 	w->setParent(this);
 	w->callback(cb_closeChild); // you can pass params: w->callback(cb_closeChild, (void*)params)
 	subWindows.push_back(w);
 	//debug();
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
-void gdWindow::delSubWindow(gdWindow *w)
+void gdWindow::delSubWindow(gdWindow* w)
 {
-	for (unsigned i=0; i<subWindows.size(); i++)
-		if (w->getId() == subWindows.at(i)->getId()) {
-			delete subWindows.at(i);
-			subWindows.erase(subWindows.begin() + i);
-			//debug();
+	for (unsigned j = 0; j < subWindows.size(); j++)
+		if (w->getId() == subWindows.at(j)->getId())
+		{
+			delete subWindows.at(j);
+			subWindows.erase(subWindows.begin() + j);
 			return;
 		}
-	//debug();
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
-void gdWindow::delSubWindow(int id)
+void gdWindow::delSubWindow(int wid)
 {
-	for (unsigned i=0; i<subWindows.size(); i++)
-		if (subWindows.at(i)->getId() == id) {
-			delete subWindows.at(i);
-			subWindows.erase(subWindows.begin() + i);
-			//debug();
+	for (unsigned j = 0; j < subWindows.size(); j++)
+		if (subWindows.at(j)->getId() == wid)
+		{
+			delete subWindows.at(j);
+			subWindows.erase(subWindows.begin() + j);
 			return;
 		}
-	//debug();
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
-int gdWindow::getId()
+int gdWindow::getId() const
 {
 	return id;
 }
 
-
-void gdWindow::setId(int id)
+void gdWindow::setId(int wid)
 {
-	this->id = id;
+	id = wid;
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
-void gdWindow::debug()
+void gdWindow::debug() const
 {
-	gu_log("---- window stack (id=%d): ----\n", getId());
+	/* TODO - use G_DEBUG
+	u::log::print("---- window stack (id=%d): ----\n", getId());
 	for (unsigned i=0; i<subWindows.size(); i++)
-		gu_log("[gdWindow] %p (id=%d)\n", (void*)subWindows.at(i), subWindows.at(i)->getId());
-	gu_log("----\n");
+		u::log::print("[gdWindow] %p (id=%d)\n", (void*)subWindows.at(i), subWindows.at(i)->getId());
+	u::log::print("----\n");
+	*/
 }
 
-
 /* -------------------------------------------------------------------------- */
 
+geompp::Rect<int> gdWindow::getContentBounds() const
+{
+	return {0, 0, w(), h()};
+}
 
-gdWindow *gdWindow::getParent()
+/* -------------------------------------------------------------------------- */
+
+gdWindow* gdWindow::getParent()
 {
 	return parent;
 }
 
-
-void gdWindow::setParent(gdWindow *w)
+void gdWindow::setParent(gdWindow* w)
 {
 	parent = w;
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
-bool gdWindow::hasWindow(int id)
+bool gdWindow::hasWindow(int wid) const
 {
-	for (unsigned i=0; i<subWindows.size(); i++)
-		if (id == subWindows.at(i)->getId())
+	for (unsigned j = 0; j < subWindows.size(); j++)
+		if (wid == subWindows.at(j)->getId())
 			return true;
 	return false;
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
-gdWindow *gdWindow::getChild(int id)
+gdWindow* gdWindow::getChild(int wid)
 {
-	for (unsigned i=0; i<subWindows.size(); i++)
-		if (id == subWindows.at(i)->getId())
-			return subWindows.at(i);
+	for (unsigned j = 0; j < subWindows.size(); j++)
+		if (wid == subWindows.at(j)->getId())
+			return subWindows.at(j);
 	return nullptr;
 }
+} // namespace giada::v
