@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2022 Giovanni A. Zuliani | Monocasual Laboratories
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,54 +24,56 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GD_WINDOW_H
 #define GD_WINDOW_H
 
-
-#include <vector>
+#include "deps/geompp/src/rect.hpp"
 #include <FL/Fl_Double_Window.H>
+#include <vector>
 
-
-/* cb_window_closer
- * callback for when closing windows. Deletes the widget (delete). */
-
-void __cb_window_closer(Fl_Widget* v, void* p);
-
-
+namespace giada::v
+{
 class gdWindow : public Fl_Double_Window
 {
-protected:
-
-	std::vector<gdWindow*> subWindows;
-	int id;
-	gdWindow* parent;
-
 public:
-
-	gdWindow(int x, int y, int w, int h, const char* title=0, int id=0);
-	gdWindow(int w, int h, const char* title=0, int id=0);
+	gdWindow(int x, int y, int w, int h, const char* title = 0, int id = 0);
+	gdWindow(int w, int h, const char* title = 0, int id = 0);
+	gdWindow(geompp::Rect<int>, const char* title = 0, int id = 0);
 	~gdWindow();
 
-	static void cb_closeChild(Fl_Widget* v, void* p);
+	static void cb_closeChild(Fl_Widget* /*w*/, void* p);
 
-	void addSubWindow(gdWindow* w);
-	void delSubWindow(gdWindow* w);
-	void delSubWindow(int id);
+	/* rebuild, refresh
+	Rebuild() is called by the View Updater when something structural changes
+	(e.g. a new channel added). Refresh() is called periodically by the View 
+	Updater during the refresh loop. */
 
-	int  getId();
-	void setId(int id);
-	void debug();
+	virtual void rebuild(){};
+	virtual void refresh(){};
 
-	void setParent(gdWindow* w);
+	/* hasWindow
+	True if the window with id 'id' exists in the stack. */
+
+	bool hasWindow(int id) const;
+
+	int  getId() const;
+	void debug() const;
+
+	geompp::Rect<int> getContentBounds() const;
+
+	void      addSubWindow(gdWindow* w);
+	void      delSubWindow(gdWindow* w);
+	void      delSubWindow(int id);
+	void      setId(int id);
+	void      setParent(gdWindow* w);
 	gdWindow* getParent();
 	gdWindow* getChild(int id);
 
-	/* hasWindow
-	 * true if the window with id 'id' exists in the stack. */
-
-	bool hasWindow(int id);
+protected:
+	std::vector<gdWindow*> subWindows;
+	int                    id;
+	gdWindow*              parent;
 };
-
+} // namespace giada::v
 
 #endif
