@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2022 Giovanni A. Zuliani | Monocasual Laboratories
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,59 +24,40 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GE_GRID_TOOL_H
 #define GE_GRID_TOOL_H
 
-
-#include <vector>
+#include "core/conf.h"
+#include "core/types.h"
 #include <FL/Fl_Group.H>
 
-
-class geChoice;
 class geCheck;
-class gdActionEditor;
-
 
+namespace giada::v
+{
+class geChoice;
 class geGridTool : public Fl_Group
 {
-private:
-
-  geChoice *gridType;
-	geCheck  *active;
-
-	gdActionEditor *parent;
-
-	static void cb_changeType(Fl_Widget *w, void *p);
-	inline void __cb_changeType();
-
 public:
-
-	geGridTool(int x, int y, gdActionEditor *parent);
+	geGridTool(Pixel x, Pixel y, m::Conf::Data&);
 	~geGridTool();
 
-	int  getValue();
-	bool isOn();
-	void calc();
+	int  getValue() const;
+	bool isOn() const;
 
-	/* getSnapPoint
-	 * given a cursor position in input, return the x coordinates of the
-	 * nearest snap point (in pixel, clean, ie. not x()-shifted) */
-
-	int getSnapPoint(int v);
-	int getSnapFrame(int v);
+	Frame getSnapFrame(Frame f, Frame framesInBeat) const;
 
 	/* getCellSize
-	 * return the size in pixel of a single cell of the grid. */
+	Returns the size in frames of a single cell of the grid. */
 
-	int getCellSize();
+	Frame getCellSize(Frame framesInBeat) const;
 
-	std::vector<int> points;   // points of the grid
-	std::vector<int> frames;   // frames of the grid
+private:
+	m::Conf::Data& m_conf;
 
-	std::vector<int> bars;
-	std::vector<int> beats;
+	geChoice* gridType;
+	geCheck*  active;
 };
-
+} // namespace giada::v
 
 #endif
