@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2022 Giovanni A. Zuliani | Monocasual Laboratories
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,73 +24,33 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GE_PIANO_ITEM_H
 #define GE_PIANO_ITEM_H
 
+#include "baseAction.h"
 
-#include "../../../core/recorder.h"
-#include "../../../core/midiEvent.h"
-#include "basePianoItem.h"
-
-
-class gdActionEditor;
-
-
-class gePianoItem : public geBasePianoItem
+namespace giada::m
 {
-private:
-
-	struct giada::m::recorder::action a;
-	struct giada::m::recorder::action b;
-
-	int push_x;
-
-	/* changed
-	If Item has been moved or resized: re-recording needed. */
-
-	bool changed;
-
-	/* onLeft, RightEdge
-	If cursor is on a widget's edge. */
-
-	bool onLeftEdge;
-	bool onRightEdge;
-
-	/* old_x, old_w
-	Store previous width and position while dragging and moving, in order to 
-	restore it if overlap. */
-
-	int old_x, old_w;
-
-	/* getRelX/Y
-	Returns x/y point of this item, relative to piano roll (and not to entire 
-	screen). */
-
-	int getRelY();
-	int getRelX();
-
-	/* overlap
-	Checks if this item don't overlap with another one. */
-
-	bool overlap();
+struct Action;
+}
 
+namespace giada::v
+{
+class gePianoItem : public geBaseAction
+{
 public:
+	gePianoItem(int x, int y, int w, int h, m::Action a1, m::Action a2);
 
-	static const int MIN_WIDTH    = 10;
-	static const int HANDLE_WIDTH = 5;
-
-	gePianoItem(int x, int y, int rel_x, int rel_y, 
-		struct giada::m::recorder::action a, struct giada::m::recorder::action b, 
-		gdActionEditor* pParent);
- 
 	void draw() override;
-	int handle(int e) override;
 
-  void reposition(int pianoRollX) override;
+	bool isResizable() const;
 
-	void removeAction();
+private:
+	bool m_ringLoop;
+	bool m_orphaned;
+
+	Pixel calcVelocityH() const;
 };
-
+} // namespace giada::v
 
 #endif
