@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2022 Giovanni A. Zuliani | Monocasual Laboratories
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,32 +24,57 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GE_PIANO_ROLL_H
 #define GE_PIANO_ROLL_H
 
-
-#include <FL/fl_draw.H>
 #include "baseActionEditor.h"
+#include <FL/fl_draw.H>
 
+namespace giada::m
+{
+struct Action;
+}
 
-class gdActionEditor;
-
-
+namespace giada::v
+{
 class gePianoRoll : public geBaseActionEditor
 {
-private:
+public:
+	static const int   MAX_KEYS    = 127;
+	static const int   MAX_OCTAVES = 9;
+	static const int   KEYS        = 12;
+	static const Pixel CELL_H      = 20;
+	static const Pixel CELL_W      = 40;
 
+	gePianoRoll(Pixel x, Pixel y, gdBaseActionEditor* b);
+
+	void draw() override;
+	int  handle(int e) override;
+
+	void rebuild(c::actionEditor::Data& d) override;
+
+private:
 	enum class Notes
 	{
-		G = 1, FS = 2, F = 3, E = 4, DS = 5, D = 6, CS = 7, C = 8, B = 9, AS = 10,
-		A = 11, GS = 0
+		G  = 1,
+		FS = 2,
+		F  = 3,
+		E  = 4,
+		DS = 5,
+		D  = 6,
+		CS = 7,
+		C  = 8,
+		B  = 9,
+		AS = 10,
+		A  = 11,
+		GS = 0
 	};
 
-	int push_y;
-
-	Fl_Offscreen surface1;  // notes, no repeat
-	Fl_Offscreen surface2;  // lines, x-repeat
+	void onAddAction() override;
+	void onDeleteAction() override;
+	void onMoveAction() override;
+	void onResizeAction() override;
+	void onRefreshAction() override;
 
 	/* drawSurface*
 	Generates a complex drawing in memory first and copy it to the screen at a
@@ -59,34 +84,23 @@ private:
 	containing the rest of the piano roll. The latter will then be tiled during
 	the ::draw() call. */
 
-	void drawSurface1();
-	void drawSurface2();
+	void drawSurfaceY();
+	void drawSurfaceX();
 
+	Pixel snapToY(Pixel p) const;
+	int   yToNote(Pixel y) const;
+	Pixel noteToY(int n) const;
+	Pixel getPianoItemW(Pixel x, const m::Action& a1, const m::Action& a2) const;
 
-	void build();
+	Fl_Offscreen surfaceY; // vertical notes, no x-repeat
+	Fl_Offscreen surfaceX; // lines, x-repeat
 
-public:
+	/* m_pick
+	Y-coordinate of the click event when the user clicks on an empty area of the
+	piano roll. Used for right mouse button scrolling. */
 
-	static const int MAX_KEYS    = 127;
-	static const int MAX_OCTAVES = 9;
-	static const int KEYS        = 12;
-	static const int CELL_H      = 18;
-	static const int CELL_W      = 40;
-
-	gePianoRoll(int x, int y, int w, gdActionEditor* pParent);
-
-	void draw() override;
-	int  handle(int e) override;
-
-  /* updateActions
-  Repositions existing actions after a zoom gesture. */
-  
-	void updateActions() override;
-
-	void recordAction(int note, int frame_a, int frame_b=0);
-
-	int yToNote(int y);
+	Pixel m_pick;
 };
-
+} // namespace giada::v
 
 #endif
