@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2022 Giovanni A. Zuliani | Monocasual Laboratories
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,18 +24,45 @@
  *
  * -------------------------------------------------------------------------- */
 
-
-#include "../../../core/const.h"
 #include "box.h"
+#include "core/const.h"
+#include "utils/gui.h"
+#include <FL/fl_draw.H>
 
-
-geBox::geBox(int x, int y, int w, int h, const char *l, Fl_Align al)
+namespace giada::v
+{
+geBox::geBox(int x, int y, int w, int h, const char* l, Fl_Align al)
 : Fl_Box(x, y, w, h)
 {
-  copy_label(l);
-  labelsize(G_GUI_FONT_SIZE_BASE);
-  box(FL_NO_BOX);
-  labelcolor(G_COLOR_LIGHT_2);
-  if (al != 0)
-    align(al | FL_ALIGN_INSIDE);
+	copy_label(l);
+	box(FL_NO_BOX);
+	color(G_COLOR_GREY_1);
+	align(al | FL_ALIGN_INSIDE);
 }
+
+/* -------------------------------------------------------------------------- */
+
+geBox::geBox(const char* l, Fl_Align al)
+: geBox(0, 0, 0, 0, l, al)
+{
+}
+
+/* -------------------------------------------------------------------------- */
+
+void geBox::draw()
+{
+	fl_rectf(x(), y(), w(), h(), color()); // Clear background
+
+	if (box() != FL_NO_BOX)
+		fl_rect(x(), y(), w(), h(), G_COLOR_GREY_4); // Border
+
+	if (image() != nullptr)
+		draw_label(); // draw_label also paints image, if any
+	else if (label() != nullptr)
+	{
+		fl_color(active() ? G_COLOR_LIGHT_2 : G_COLOR_GREY_4);
+		fl_font(FL_HELVETICA, G_GUI_FONT_SIZE_BASE);
+		fl_draw(giada::u::gui::truncate(label(), w()).c_str(), x(), y(), w(), h(), align());
+	}
+}
+} // namespace giada::v
\ No newline at end of file
