@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2022 Giovanni A. Zuliani | Monocasual Laboratories
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,20 +24,21 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GE_BOX_H
 #define GE_BOX_H
 
-
 #include <FL/Fl_Box.H>
 
-
+namespace giada::v
+{
 class geBox : public Fl_Box
 {
 public:
+	geBox(int x, int y, int w, int h, const char* l = nullptr, Fl_Align al = FL_ALIGN_CENTER);
+	geBox(const char* l = nullptr, Fl_Align al = FL_ALIGN_CENTER);
 
-  geBox(int x, int y, int w, int h, const char *l=0, Fl_Align al=FL_ALIGN_CENTER);
+	void draw() override;
 };
-
+} // namespace giada::v
 
 #endif
