@@ -7,7 +7,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2022 Giovanni A. Zuliani | Monocasual Laboratories
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -27,30 +27,42 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GE_BUTTON_H
 #define GE_BUTTON_H
 
+#include <FL/Fl_Button.H>
+#include <functional>
 
-#include "baseButton.h"
-
-
-class geButton : public geBaseButton
+namespace giada::v
+{
+class geButton : public Fl_Button
 {
 public:
+	geButton(int x, int y, int w, int h, const char* l = nullptr,
+	    const char** imgOff = nullptr, const char** imgOn = nullptr,
+	    const char** imgDisabled = nullptr);
 
-  geButton(int x, int y, int w, int h, const char *L=0,
-    const char **imgOff=nullptr, const char **imgOn=nullptr);
+	geButton(const char* l = nullptr, const char** imgOff = nullptr,
+	    const char** imgOn = nullptr, const char** imgDisabled = nullptr);
 
-  void draw() override;
+	void draw() override;
 
-  const char **imgOff;
-	const char **imgOn;
-	Fl_Color bgColor0;   // background not clicked
-	Fl_Color bgColor1;   // background clicked
-	Fl_Color bdColor;    // border
-	Fl_Color txtColor;	 // text
+	std::function<void()> onClick;
+
+protected:
+	static void cb_click(Fl_Widget*, void*);
+
+	void draw(const char** img, Fl_Color bgColor, Fl_Color textColor);
+
+	const char** imgOff;
+	const char** imgOn;
+	const char** imgDisabled;
+
+	Fl_Color bgColor0; // background not clicked
+	Fl_Color bgColor1; // background clicked
+	Fl_Color bdColor;  // border
+	Fl_Color txtColor; // text
 };
-
+} // namespace giada::v
 
 #endif
