@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2022 Giovanni A. Zuliani | Monocasual Laboratories
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,22 +24,26 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GE_DIAL_H
 #define GE_DIAL_H
 
-
 #include <FL/Fl_Dial.H>
+#include <functional>
 
-
+namespace giada::v
+{
 class geDial : public Fl_Dial
 {
 public:
+	geDial(int x, int y, int w, int h, const char* l = 0);
 
-	geDial(int x, int y, int w, int h, const char *l=0);
+	void draw() override;
 
-	void draw();
+	std::function<void(float)> onChange;
+
+private:
+	static void cb_change(Fl_Widget*, void*);
 };
-
+} // namespace giada::v
 
 #endif
