@@ -9,7 +9,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2022 Giovanni A. Zuliani | Monocasual Laboratories
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -29,22 +29,47 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GE_LIQUID_SCROLL_H
 #define GE_LIQUID_SCROLL_H
 
+#include "core/const.h"
+#include "deps/geompp/src/rect.hpp"
+#include "gui/types.h"
+#include "scroll.h"
 
-#include <FL/Fl_Scroll.H>
-
-
-class geLiquidScroll : public Fl_Scroll
+namespace giada::v
+{
+class geLiquidScroll : public geScroll
 {
 public:
+	geLiquidScroll(int x, int y, int w, int h, Direction d);
+	geLiquidScroll(geompp::Rect<int>, Direction d);
 
-	geLiquidScroll(int x, int y, int w, int h, const char *l=0);
+	void resize(int x, int y, int w, int h) override;
 
-	void resize(int x, int y, int w, int h);
+	/* addWidget
+    Adds a new widget to the bottom, with proper spacing. */
+
+	template <typename T>
+	T* addWidget(T* wg)
+	{
+		int numChildren = countChildren();
+
+		int wx = x();
+		int wy = y() - yposition() + (numChildren * (wg->h() + G_GUI_INNER_MARGIN));
+		int ww = w() - 24;
+		int wh = wg->h();
+
+		wg->resize(wx, wy, ww, wh);
+		add(wg);
+		redraw();
+
+		return wg;
+	}
+
+private:
+	Direction m_direction;
 };
-
+} // namespace giada::v
 
 #endif
