@@ -7,7 +7,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2017 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2022 Giovanni A. Zuliani | Monocasual Laboratories
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -27,25 +27,31 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GE_STATUS_BUTTON_H
 #define GE_STATUS_BUTTON_H
 
-
 #include "button.h"
 
-
+namespace giada::v
+{
 class geStatusButton : public geButton
 {
 public:
+	geStatusButton(int x, int y, int w, int h, const char** imgOff = nullptr,
+	    const char** imgOn = nullptr, const char** imgDisabled = nullptr);
 
-	geStatusButton(int x, int y, int w, int h, const char **imgOff=nullptr,
-    const char **imgOn=nullptr);
+	geStatusButton(const char** imgOff = nullptr, const char** imgOn = nullptr,
+	    const char** imgDisabled = nullptr);
 
 	void draw() override;
 
-	bool status;
-};
+	bool getStatus() const;
 
+	void setStatus(bool s);
+
+private:
+	bool m_status;
+};
+} // namespace giada::v
 
 #endif
