@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2022 Giovanni A. Zuliani | Monocasual Laboratories
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,61 +24,68 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GE_TAB_AUDIO_H
 #define GE_TAB_AUDIO_H
 
-
+#include "deps/geompp/src/rect.hpp"
+#include "glue/config.h"
+#include "gui/elems/basics/choice.h"
 #include <FL/Fl_Group.H>
 
-
-class geChoice;
 class geCheck;
-class geButton;
 class geInput;
 
-
+namespace giada::v
+{
 class geTabAudio : public Fl_Group
 {
-private:
-
-	static void cb_deactivate_sounddev(Fl_Widget *w, void *p);
-	static void cb_fetchInChans       (Fl_Widget *w, void *p);
-	static void cb_fetchOutChans      (Fl_Widget *w, void *p);
-	static void cb_showInputInfo      (Fl_Widget *w, void *p);
-	static void cb_showOutputInfo     (Fl_Widget *w, void *p);
-	inline void __cb_deactivate_sounddev();
-	inline void __cb_fetchInChans();
-	inline void __cb_fetchOutChans();
-	inline void __cb_showInputInfo();
-	inline void __cb_showOutputInfo();
-
-	void fetchSoundDevs();
-	void fetchInChans(int menuItem);
-	void fetchOutChans(int menuItem);
-	int  findMenuDevice(geChoice *m, int device);
-
-	int soundsysInitValue;
-
 public:
+	struct geDeviceMenu : public geChoice
+	{
+		geDeviceMenu(const char* l, const std::vector<c::config::AudioDeviceData>&);
+	};
 
-	geChoice *soundsys;
-	geChoice *samplerate;
-	geChoice *rsmpQuality;
-	geChoice *sounddevIn;
-	geButton  *devInInfo;
-	geChoice *channelsIn;
-	geChoice *sounddevOut;
-	geButton  *devOutInfo;
-	geChoice *channelsOut;
-	geCheck  *limitOutput;
-	geChoice *buffersize;
-	geInput  *delayComp;
+	struct geChannelMenu : public geChoice
+	{
+		geChannelMenu(const char* l, const c::config::AudioDeviceData&);
 
-	geTabAudio(int x, int y, int w, int h);
+		int getChannelsCount() const;
+		int getChannelsStart() const;
+
+		void rebuild(const c::config::AudioDeviceData&);
+
+	private:
+		static constexpr int STEREO_OFFSET = 1000;
+
+		c::config::AudioDeviceData m_data;
+	};
+
+	geTabAudio(geompp::Rect<int>);
 
 	void save();
-};
 
+	geChoice*      soundsys;
+	geChoice*      buffersize;
+	geChoice*      samplerate;
+	geDeviceMenu*  sounddevOut;
+	geChannelMenu* channelsOut;
+	geCheck*       limitOutput;
+	geDeviceMenu*  sounddevIn;
+	geCheck*       enableIn;
+	geChannelMenu* channelsIn;
+	geInput*       recTriggerLevel;
+	geChoice*      rsmpQuality;
+
+private:
+	void invalidate();
+	void fetch();
+	void deactivateAll();
+	void activateAll();
+
+	c::config::AudioData m_data;
+
+	int m_initialApi;
+};
+} // namespace giada::v
 
 #endif
