@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2022 Giovanni A. Zuliani | Monocasual Laboratories
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,45 +24,41 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GE_TAB_MIDI_H
 #define GE_TAB_MIDI_H
 
-
+#include "deps/geompp/src/rect.hpp"
+#include "glue/config.h"
 #include <FL/Fl_Group.H>
 
-
-class geChoice;
 class geCheck;
 
-
+namespace giada::v
+{
+class geStringMenu;
+class geChoice;
 class geTabMidi : public Fl_Group
 {
-private:
-
-	void fetchSystems();
-	void fetchOutPorts();
-	void fetchInPorts();
-	void fetchMidiMaps();
-
-	static void cb_changeSystem  (Fl_Widget *w, void *p);
-	inline void __cb_changeSystem();
-
-	int systemInitValue;
-
 public:
+	geTabMidi(geompp::Rect<int>);
 
-	geChoice *system;
-	geChoice *portOut;
-	geChoice *portIn;
-	geCheck  *noNoteOff;
-	geChoice *midiMap;
-	geChoice *sync;
+	void save() const;
 
-	geTabMidi(int x, int y, int w, int h);
+	geChoice*     system;
+	geStringMenu* portOut;
+	geStringMenu* portIn;
+	geCheck*      enableOut;
+	geCheck*      enableIn;
+	geStringMenu* midiMap;
+	geChoice*     sync;
 
-	void save();
+private:
+	void invalidate();
+
+	c::config::MidiData m_data;
+
+	int m_initialApi;
 };
-
+} // namespace giada::v
 
 #endif
