@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2022 Giovanni A. Zuliani | Monocasual Laboratories
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,26 +24,31 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GE_TAB_MISC_H
 #define GE_TAB_MISC_H
 
-
+#include "deps/geompp/src/rect.hpp"
+#include "glue/config.h"
 #include <FL/Fl_Group.H>
 
-
+namespace giada::v
+{
 class geChoice;
-
-
+class geStringMenu;
 class geTabMisc : public Fl_Group
 {
 public:
-
-	geChoice *debugMsg;
-
-	geTabMisc(int x, int y, int w, int h);
+	geTabMisc(geompp::Rect<int>);
 
 	void save();
+
+private:
+	c::config::MiscData m_data;
+
+	geChoice*     m_debugMsg;
+	geChoice*     m_tooltips;
+	geStringMenu* m_langMap;
 };
+} // namespace giada::v
 
 #endif
