@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2022 Giovanni A. Zuliani | Monocasual Laboratories
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,29 +24,62 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GE_CHANNEL_H
 #define GE_CHANNEL_H
 
-
+#include "core/types.h"
+#include "glue/channel.h"
 #include <FL/Fl_Group.H>
 
-
-class Channel;
-class geIdButton;
-class geChannelStatus;
-class geButton;
-class geChannelButton;
+namespace giada::v
+{
 class geDial;
-#ifdef WITH_VST
+class geButton;
+class geChannelStatus;
 class geStatusButton;
-#endif
-
-
+class geChannelButton;
+class geMidiActivity;
 class geChannel : public Fl_Group
 {
-protected:
+public:
+	geChannel(int x, int y, int w, int h, c::channel::Data d);
 
+	void draw() override;
+
+	/* refresh
+	Updates graphics. */
+
+	virtual void refresh();
+
+	/* getColumnId
+	Returns the ID of the column this channel resides in. */
+
+	ID getColumnId() const;
+
+	/* handleKey
+	Performs some UI-related operations when the bound key is pressed. Returns
+	whether the bound key has been pressed or not. */
+
+	bool handleKey(int e);
+
+	/* getData
+	Returns a reference to the internal data. Read-only. */
+
+	const c::channel::Data& getData() const;
+
+	geStatusButton*  playButton;
+	geButton*        arm;
+	geChannelStatus* status;
+	geChannelButton* mainButton;
+	geMidiActivity*  midiActivity;
+	geStatusButton*  mute;
+	geStatusButton*  solo;
+	geDial*          vol;
+#ifdef WITH_VST
+	geStatusButton* fx;
+#endif
+
+protected:
 	/* Define some breakpoints for dynamic resize. BREAK_DELTA: base amount of
 	pixels to shrink sampleButton. */
 
@@ -61,96 +94,36 @@ protected:
 	static const int BREAK_ARM          = 168;
 #endif
 
-	static const int MIN_ELEM_W = 20;
-
-	static void cb_arm(Fl_Widget* v, void* p);
-	static void cb_mute(Fl_Widget* v, void* p);
-	static void cb_solo(Fl_Widget* v, void* p);
-	static void cb_changeVol(Fl_Widget* v, void* p);
+	static void cb_arm(Fl_Widget* /*w*/, void* p);
+	static void cb_mute(Fl_Widget* /*w*/, void* p);
+	static void cb_solo(Fl_Widget* /*w*/, void* p);
+	static void cb_changeVol(Fl_Widget* /*w*/, void* p);
 #ifdef WITH_VST
-		static void cb_openFxWindow(Fl_Widget* v, void* p);
+	static void cb_openFxWindow(Fl_Widget* /*w*/, void* p);
 #endif
 	void cb_mute();
 	void cb_arm();
 	void cb_solo();
 	void cb_changeVol();
 #ifdef WITH_VST
-		void cb_openFxWindow();
+	void cb_openFxWindow();
 #endif
 
 	/* blink
-	 * blink button when channel is in wait/ending status. */
+	Blinks button when channel is in wait/ending status. */
 
 	void blink();
 
-	/* setColorByStatus
-	 * update colors depending on channel status. */
-
-	void setColorsByStatus(int playStatus, int recStatus);
-
-	/* handleKey
-	 * method wrapped by virtual handle(int e). */
-
-	int handleKey(int e, int key);
-
 	/* packWidgets
 	Spread widgets across available space. */
 
 	void packWidgets();
 
-public:
+	/* m_channel
+	Channel's data. */
 
-	geChannel(int x, int y, int w, int h, int type, Channel* ch);
-
-	/* reset
-	 * reset channel to initial status. */
-
-	virtual void reset() = 0;
-
-	/* update
-	 * update the label of sample button and everything else such as 'R'
-	 * button, key box and so on, according to global values. */
-
-	virtual void update() = 0;
-
-	/* refresh
-	 * update graphics. */
-
-	virtual void refresh() = 0;
-
-	/* changeSize
-	Changes channel's size according to a template (x1, x2, ...). */
-
-	virtual void changeSize(int h);
-
-	/* keypress
-	 * what to do when the corresponding key is pressed. */
-
-	int keyPress(int event);
-
-	/* getColumnIndex
-	 * return the numeric index of the column in which this channel is
-	 * located. */
-
-	int getColumnIndex();
-
-	int getSize();
-
-	Channel* ch;
- 
-	geIdButton*      button;
-	geChannelStatus* status;
-	geButton*        arm;
-	geChannelButton* mainButton;
-	geButton*        mute;
-	geButton*        solo;
-	geDial*          vol;
-#ifdef WITH_VST
-	geStatusButton*  fx;
-#endif
-
-	int type;
+	c::channel::Data m_channel;
 };
-
+} // namespace giada::v
 
 #endif
