@@ -6,7 +6,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2017 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2022 Giovanni A. Zuliani | Monocasual Laboratories
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -26,22 +26,27 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GE_CHANNEL_STATUS_H
 #define GE_CHANNEL_STATUS_H
 
-
 #include <FL/Fl_Box.H>
 
-
+namespace giada::c::channel
+{
+struct Data;
+}
+namespace giada::v
+{
 class geChannelStatus : public Fl_Box
 {
 public:
-	geChannelStatus(int X, int Y, int W, int H, class SampleChannel *ch,
-    const char *L=0);
-	void draw();
-	class SampleChannel *ch;
-};
+	geChannelStatus(int x, int y, int w, int h, c::channel::Data& d);
 
+	void draw() override;
+
+private:
+	c::channel::Data& m_channel;
+};
+} // namespace giada::v
 
 #endif
