@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2022 Giovanni A. Zuliani | Monocasual Laboratories
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,75 +24,57 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GE_COLUMN_H
 #define GE_COLUMN_H
 
-
+#include "core/types.h"
+#include "glue/channel.h"
 #include <FL/Fl_Group.H>
+#include <functional>
+#include <vector>
 
-
-class Channel;
+namespace giada::v
+{
 class geButton;
-class geChannel;
 class geResizerBar;
 class geKeyboard;
-
-
+class geChannel;
 class geColumn : public Fl_Group
 {
-private:
-
-	static void cb_addChannel  (Fl_Widget* v, void* p);
-	inline void __cb_addChannel();
-
-	int openTypeMenu();
-
-	geButton*     m_addChannelBtn;
-	geResizerBar* m_resizer;
-	geKeyboard*   m_parent;
-
-	int m_index;
-
 public:
+	geColumn(int x, int y, int w, int h, ID id, geResizerBar* b);
 
-	geColumn(int x, int y, int w, int h, int index, geKeyboard* parent);
-	~geColumn();
+	geChannel* getChannel(ID channelId) const;
 
 	/* addChannel
-	Adds a new channel in this column and set the internal pointer to channel 
-	to 'ch'. */
+	Adds a new channel in this column. */
 
-	geChannel* addChannel(Channel* ch, int size);
-
-	int handle(int e) override;
-	void draw() override;
-  void resize(int x, int y, int w, int h) override;
-
-	/* clear
-	Removes all channels from the column. If full==true, delete also the "add new 
-	channel" button. */
-
-	void clear(bool full=false);
-
-	/* deleteChannel
-	Removes the channel 'gch' from this column. */
-
-	void deleteChannel(geChannel* gch);
-
-	void repositionChannels();
+	geChannel* addChannel(c::channel::Data d);
 
 	/* refreshChannels
 	Updates channels' graphical statues. Called on each GUI cycle. */
 
-	void refreshChannels();
+	void refresh();
 
-	Channel* getChannel(int i);
-	int getIndex();
-	void setIndex(int i);
-	bool isEmpty();   
-  int countChannels();
+	void init();
+
+	void forEachChannel(std::function<void(geChannel& c)> f) const;
+
+	ID id;
+
+	geResizerBar* resizerBar;
+
+private:
+	static void cb_addChannel(Fl_Widget* /*w*/, void* p);
+	void        cb_addChannel();
+
+	int countChannels() const;
+	int computeHeight() const;
+
+	std::vector<geChannel*> m_channels;
+
+	geButton* m_addChannelBtn;
 };
-
+} // namespace giada::v
 
 #endif
