@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2022 Giovanni A. Zuliani | Monocasual Laboratories
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,39 +24,32 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GE_MIDI_CHANNEL_H
 #define GE_MIDI_CHANNEL_H
 
-
 #include "channel.h"
 #include "channelButton.h"
 
-
-class MidiChannel;
-
-
+namespace giada
+{
+namespace v
+{
 class geMidiChannel : public geChannel
 {
-private:
-
-	static void cb_button(Fl_Widget* v, void* p);
-	static void cb_openMenu(Fl_Widget* v, void* p);
-	void cb_button();
-	void cb_openMenu();
-
 public:
-
-	geMidiChannel(int x, int y, int w, int h, MidiChannel* ch);
+	geMidiChannel(int x, int y, int w, int h, c::channel::Data d);
 
 	void resize(int x, int y, int w, int h) override;
 
-	void reset() override;
-	void update() override;
-	void refresh() override;
+  private:
+	static void cb_playButton(Fl_Widget* /*w*/, void* p);
+	static void cb_openMenu(Fl_Widget* /*w*/, void* p);
+	void        cb_playButton();
+	void        cb_openMenu();
 
-	int keyPress(int event);  // TODO - move to base class
+	c::channel::Data m_data;
 };
-
+} // namespace v
+} // namespace giada
 
 #endif
