@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2022 Giovanni A. Zuliani | Monocasual Laboratories
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,20 +24,26 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GE_MIDI_CHANNEL_BUTTON_H
 #define GE_MIDI_CHANNEL_BUTTON_H
 
-
 #include "channelButton.h"
 
-
+namespace giada
+{
+namespace v
+{
 class geMidiChannelButton : public geChannelButton
 {
 public:
-	geMidiChannelButton(int x, int y, int w, int h, const char* l=0);
-	int handle(int e);
+	geMidiChannelButton(int x, int y, int w, int h, const c::channel::Data& d);
+
+	void refresh() override;
+
+  private:
+	void refreshLabel();
 };
+} // namespace v
+} // namespace giada
 
-
-#endif
\ No newline at end of file
+#endif
