@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2022 Giovanni A. Zuliani | Monocasual Laboratories
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,50 +24,37 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GE_SAMPLE_CHANNEL_H
 #define GE_SAMPLE_CHANNEL_H
 
-
 #include "channel.h"
+#include "glue/channel.h"
 
-
-class SampleChannel;
+namespace giada::v
+{
+class geStatusButton;
 class geChannelMode;
-class geButton;
-
-
 class geSampleChannel : public geChannel
 {
-private:
-
-	static void cb_button     (Fl_Widget* v, void* p);
-	static void cb_openMenu   (Fl_Widget* v, void* p);
-	static void cb_readActions(Fl_Widget* v, void* p);
-	void __cb_button     ();
-	void __cb_openMenu   ();
-	void __cb_readActions();
-
 public:
-
-	geSampleChannel(int x, int y, int w, int h, SampleChannel* ch);
+	geSampleChannel(int x, int y, int w, int h, c::channel::Data d);
 
 	void resize(int x, int y, int w, int h) override;
+	void draw() override;
 
-	void reset() override;
-	void update() override;
 	void refresh() override;
-	void changeSize(int h) override;
 
-	/* show/hideActionButton
-	Adds or removes 'R' button when actions are available. */
+	geChannelMode*  modeBox;
+	geStatusButton* readActions;
 
-	void showActionButton();
-	void hideActionButton();
-
-	geChannelMode* modeBox;
-	geButton*      readActions;
+private:
+	static void cb_playButton(Fl_Widget* /*w*/, void* p);
+	static void cb_openMenu(Fl_Widget* /*w*/, void* p);
+	static void cb_readActions(Fl_Widget* /*w*/, void* p);
+	void        cb_playButton();
+	void        cb_openMenu();
+	void        cb_readActions();
 };
-
+} // namespace giada::v
 
 #endif
