@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2022 Giovanni A. Zuliani | Monocasual Laboratories
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,21 +24,25 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GE_SAMPLE_CHANNEL_BUTTON_H
 #define GE_SAMPLE_CHANNEL_BUTTON_H
 
-
 #include "channelButton.h"
 
-
+namespace giada
+{
+namespace v
+{
 class geSampleChannelButton : public geChannelButton
 {
 public:
+	geSampleChannelButton(int x, int y, int w, int h, const c::channel::Data& d);
 
-	geSampleChannelButton(int x, int y, int w, int h, const char* l=0);
-	int handle(int e);
+	int handle(int e) override;
+
+	void refresh() override;
 };
-
+} // namespace v
+} // namespace giada
 
 #endif
