@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2017 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2022 Giovanni A. Zuliani | Monocasual Laboratories
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,62 +24,46 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GE_MAIN_IO_H
 #define GE_MAIN_IO_H
 
+#include "glue/main.h"
+#include "gui/elems/basics/flex.h"
 
-#include <FL/Fl_Group.H>
-
+namespace giada::v
+{
+class geDial;
 class geSoundMeter;
-class geDial;
-#ifdef WITH_VST
+class geButton;
 class geStatusButton;
-class geButton;
-#endif
-
-class geMainIO : public Fl_Group
+class geMainIO : public geFlex
 {
-private:
-
-	geSoundMeter *outMeter;
-	geSoundMeter *inMeter;
-	geDial        *outVol;
-	geDial        *inVol;
-#ifdef WITH_VST
-  geStatusButton *masterFxOut;
-  geStatusButton *masterFxIn;
-  geButton       *inToOut;
-#endif
-
-	static void cb_outVol     (Fl_Widget *v, void *p);
-	static void cb_inVol      (Fl_Widget *v, void *p);
-#ifdef WITH_VST
-	static void cb_masterFxOut(Fl_Widget *v, void *p);
-	static void cb_masterFxIn (Fl_Widget *v, void *p);
-	static void cb_inToOut    (Fl_Widget *v, void *p);
-#endif
-
-	inline void __cb_outVol     ();
-	inline void __cb_inVol      ();
-#ifdef WITH_VST
-	inline void __cb_masterFxOut();
-	inline void __cb_masterFxIn ();
-	inline void __cb_inToOut    ();
-#endif
-
 public:
-
-	geMainIO(int x, int y);
+	geMainIO();
 
 	void refresh();
+	void rebuild();
 
 	void setOutVol(float v);
-	void setInVol (float v);
+	void setInVol(float v);
 #ifdef WITH_VST
 	void setMasterFxOutFull(bool v);
 	void setMasterFxInFull(bool v);
 #endif
+
+private:
+	c::main::IO m_io;
+
+	geSoundMeter* m_outMeter;
+	geSoundMeter* m_inMeter;
+	geDial*       m_outVol;
+	geDial*       m_inVol;
+	geButton*     m_inToOut;
+#ifdef WITH_VST
+	geStatusButton* m_masterFxOut;
+	geStatusButton* m_masterFxIn;
+#endif
 };
+} // namespace giada::v
 
 #endif
