@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2022 Giovanni A. Zuliani | Monocasual Laboratories
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,40 +24,22 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GE_MAIN_MENU_H
 #define GE_MAIN_MENU_H
 
+#include "gui/elems/basics/flex.h"
 
-#include <FL/Fl_Group.H>
-
-
-class geButton;
-
-
-class geMainMenu : public Fl_Group
+namespace giada::v
+{
+class geMainMenu : public geFlex
 {
-private:
-
-  geButton *file;
-  geButton *edit;
-  geButton *config;
-  geButton *about;
-
-	static void cb_about (Fl_Widget *v, void *p);
-	static void cb_config(Fl_Widget *v, void *p);
-	static void cb_file  (Fl_Widget *v, void *p);
-	static void cb_edit  (Fl_Widget *v, void *p);
-
-	inline void __cb_about ();
-	inline void __cb_config();
-	inline void __cb_file  ();
-	inline void __cb_edit  ();
-
 public:
+	geMainMenu();
 
-	geMainMenu(int x, int y);
+private:
+	void cb_file();
+	void cb_edit();
 };
-
+} // namespace giada::v
 
 #endif
