@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2022 Giovanni A. Zuliani | Monocasual Laboratories
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,30 +24,28 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifdef WITH_VST
 
 #ifndef GE_PLUGIN_BROWSER_H
 #define GE_PLUGIN_BROWSER_H
 
-
 #include <FL/Fl_Browser.H>
 
-
+namespace giada::v
+{
 class gePluginBrowser : public Fl_Browser
 {
-private:
-
-	int widths[5] = {0};
-
-	void computeWidths();
-
 public:
-
 	gePluginBrowser(int x, int y, int w, int h);
 
 	void refresh();
+
+private:
+	void computeWidths();
+
+	int m_widths[5];
 };
+} // namespace giada::v
 
 #endif
 
