@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2017 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2022 Giovanni A. Zuliani | Monocasual Laboratories
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,42 +24,42 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GE_RANGE_TOOL_H
 #define GE_RANGE_TOOL_H
 
+#include "core/types.h"
+#include "gui/elems/basics/box.h"
+#include "gui/elems/basics/button.h"
+#include "gui/elems/basics/input.h"
+#include "gui/elems/basics/pack.h"
 
-#include <FL/Fl_Group.H>
-
-
-class SampleChannel;
-class geInput;
-class geButton;
-class geBox;
-
-
-class geRangeTool : public Fl_Group
+namespace giada::c::sampleEditor
+{
+struct Data;
+}
+namespace giada::v
+{
+class geRangeTool : public gePack
 {
-private:
-
-  SampleChannel* m_ch;
-
-  geBox*    m_label;
-  geInput*  m_begin;
-  geInput*  m_end;
-  geButton* m_reset;
-
-  static void cb_setChanPos   (Fl_Widget* w, void* p);
-  static void cb_resetStartEnd(Fl_Widget* w, void* p);
-  inline void __cb_setChanPos();
-  inline void __cb_resetStartEnd();
-
 public:
+	geRangeTool(const c::sampleEditor::Data& d, int x, int y);
 
-  geRangeTool(int x, int y, SampleChannel* ch);
+	void rebuild(const c::sampleEditor::Data& d);
+	void update(Frame begin, Frame end);
 
-  void refresh();
+  private:
+	static void cb_setChanPos(Fl_Widget* /*w*/, void* p);
+	static void cb_resetStartEnd(Fl_Widget* /*w*/, void* p);
+	void        cb_setChanPos();
+	void        cb_resetStartEnd();
+
+	const c::sampleEditor::Data* m_data;
+
+	geBox    m_label;
+	geInput  m_begin;
+	geInput  m_end;
+	geButton m_reset;
 };
-
+} // namespace giada::v
 
 #endif
