@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2017 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2022 Giovanni A. Zuliani | Monocasual Laboratories
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,64 +24,80 @@
  *
  * -------------------------------------------------------------------------- */
 
-
-#include <cmath>
-#include <FL/fl_draw.H>
-#include "../../core/const.h"
-#include "../../core/kernelAudio.h"
 #include "soundMeter.h"
+#include "core/const.h"
+#include "core/kernelAudio.h"
+#include "core/types.h"
+#include "gui/drawing.h"
+#include "utils/math.h"
+#include <FL/fl_draw.H>
+#include <algorithm>
+#include <cmath>
 
-
-using namespace giada::m;
-
-
-geSoundMeter::geSoundMeter(int x, int y, int w, int h, const char *L)
-  : Fl_Box    (x, y, w, h, L),
-    clip      (false),
-    mixerPeak (0.0f),
-    peak      (0.0f),
-    dbLevel   (0.0f),
-    dbLevelOld(0.0f)
+namespace giada::v
 {
+namespace
+{
+Pixel dbToPx_(float db, Pixel max)
+{
+	const float maxf = max;
+	return std::clamp(u::math::map(db, -G_MIN_DB_SCALE, 0.0f, 0.0f, maxf), 0.0f, maxf);
+}
+} // namespace
+
+/* -------------------------------------------------------------------------- */
+/* -------------------------------------------------------------------------- */
+/* -------------------------------------------------------------------------- */
+
+float geSoundMeter::Meter::compute(float peak)
+{
+	/*  dBFS (full scale) calculation, plus decay of -2dB per call. */
+
+	float dbLevelCur = u::math::linearToDB(std::fabs(peak));
+
+	if (dbLevelCur < m_dbLevelOld && m_dbLevelOld > -G_MIN_DB_SCALE)
+		dbLevelCur = m_dbLevelOld - 2.0f;
+
+	m_dbLevelOld = dbLevelCur;
+
+	return dbLevelCur;
 }
 
+/* -------------------------------------------------------------------------- */
+/* -------------------------------------------------------------------------- */
+/* -------------------------------------------------------------------------- */
+
+geSoundMeter::geSoundMeter(int x, int y, int w, int h, const char* l)
+: Fl_Box(x, y, w, h, l)
+{
+}
 
 /* -------------------------------------------------------------------------- */
 
-
 void geSoundMeter::draw()
 {
-  fl_rect(x(), y(), w(), h(), G_COLOR_GREY_4);
+	const geompp::Rect outline(x(), y(), w(), h());
+	const geompp::Rect body(outline.reduced(1));
 
-  /* peak = the highest value inside the frame */
+	drawRect(outline, G_COLOR_GREY_4);
 
-  peak = 0.0f;
-  float tmp_peak = 0.0f;
+	if (!ready)
+	{
+		drawRectf(body, G_COLOR_BLUE);
+		return;
+	}
 
-  tmp_peak = fabs(mixerPeak);
-  if (tmp_peak > peak)
-    peak = tmp_peak;
+	drawRectf(body, G_COLOR_GREY_2); // Cleanup
 
-  clip = peak >= 1.0f ? true : false; // 1.0f is considered clip
+	const float dbL    = m_left.compute(peak.left);
+	const float dbR    = m_right.compute(peak.right);
+	const int   colorL = std::fabs(peak.left) > 1.0f ? G_COLOR_BLUE : G_COLOR_GREY_4;
+	const int   colorR = std::fabs(peak.right) > 1.0f ? G_COLOR_BLUE : G_COLOR_GREY_4;
 
+	const geompp::Rect bodyL(body.withTrimmedBottom(h() / 2));
+	const geompp::Rect bodyR(body.withTrimmedTop(h() / 2));
 
-  /*  dBFS (full scale) calculation, plus decay of -2dB per frame */
-
-  dbLevel = 20 * log10(peak);
-  if (dbLevel < dbLevelOld)
-    if (dbLevelOld > -G_MIN_DB_SCALE)
-      dbLevel = dbLevelOld - 2.0f;
-
-  dbLevelOld = dbLevel;
-
-  /* graphical part */
-
-  float px_level = 0.0f;
-  if (dbLevel < 0.0f)
-    px_level = ((w()/G_MIN_DB_SCALE) * dbLevel) + w();
-  else
-    px_level = w();
-
-  fl_rectf(x()+1, y()+1, w()-2, h()-2, G_COLOR_GREY_2);
-  fl_rectf(x()+1, y()+1, (int) px_level, h()-2, clip || !kernelAudio::getStatus() ? G_COLOR_RED_ALERT : G_COLOR_GREY_4);
+	drawRectf(bodyL.withW(dbToPx_(dbL, w() - 2)), colorL);
+	drawRectf(bodyR.withW(dbToPx_(dbR, w() - 2)), colorR);
 }
+} // namespace giada::v
\ No newline at end of file
