@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2022 Giovanni A. Zuliani | Monocasual Laboratories
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,31 +24,37 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef GE_SOUND_METER_H
 #define GE_SOUND_METER_H
 
-
+#include "core/types.h"
 #include <FL/Fl_Box.H>
 
-
+namespace giada::v
+{
 class geSoundMeter : public Fl_Box
 {
 public:
+	geSoundMeter(int x, int y, int w, int h, const char* l = 0);
 
-  geSoundMeter(int X, int Y, int W, int H, const char *L=0);
+	void draw() override;
 
-  void draw() override;
-
-  bool clip;
-	float mixerPeak;	// peak from mixer
+	Peak peak;  // Peak from Mixer
+	bool ready; // Kernel state
 
 private:
+	class Meter
+	{
+	public:
+		float compute(float peak);
 
-	float peak;
-	float dbLevel;
-	float dbLevelOld;
+	private:
+		float m_dbLevelOld = 0.0f;
+	};
+
+	Meter m_left;
+	Meter m_right;
 };
-
+} // namespace giada::v
 
 #endif
