@@ -6,7 +6,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2022 Giovanni A. Zuliani | Monocasual Laboratories
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -26,20 +26,18 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef G_UTILS_COCOA_H
 #define G_UTILS_COCOA_H
 
-
 /* fl_xid() from FLTK returns a pointer to NSWindow, but plugins on OS X want a
- * pointer to NSView. The function does the hard conversion. */
+pointer to NSView. The function does the hard conversion. */
 
-void *cocoa_getViewFromWindow(void *p);
+void* cocoa_getViewFromWindow(void* p);
 
 /* A bug on on OS X seems to misalign plugins' UI. The function takes care of
- * fixing the positioning. */
-
-void cocoa_setWindowSize(void *p, int w, int h);
+fixing the positioning. 
+TODO temporarily disabled: it does not work. */
 
+//void cocoa_setWindowSize(void *p, int w, int h);
 
 #endif
