@@ -4,7 +4,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2022 Giovanni A. Zuliani | Monocasual Laboratories
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -24,21 +24,36 @@
  *
  * -------------------------------------------------------------------------- */
 
-
-#include <cmath>
 #include "math.h"
+#include <cmath>
 
-
-float gu_linearToDB(float f)
+namespace giada
 {
-  return 20 * std::log10(f);
+namespace u
+{
+namespace math
+{
+float linearToDB(float f)
+{
+	return 20 * std::log10(f);
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
-float gu_dBtoLinear(float f)
+int quantize(int x, int step)
 {
-  return std::pow(10, f/20.0f); 
+	/* Source:
+	https://en.wikipedia.org/wiki/Quantization_(signal_processing)#Rounding_example */
+	return step * std::floor((x / (float)step) + 0.5f);
 }
+
+/* -------------------------------------------------------------------------- */
+
+float dBtoLinear(float f)
+{
+	return std::pow(10, f / 20.0f);
+}
+
+} // namespace math
+} // namespace u
+} // namespace giada
\ No newline at end of file
