@@ -6,7 +6,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2022 Giovanni A. Zuliani | Monocasual Laboratories
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -26,119 +26,97 @@
  *
  * -------------------------------------------------------------------------- */
 
-
-#include <iomanip>
-#include <cstdarg>
-#include <climits>
-#include "../core/const.h"
 #include "string.h"
+#include "core/const.h"
+#include <climits>
+#include <cstdarg>
+#include <cstddef>
+#include <iomanip>
+#include <memory>
 
-
-using std::string;
-using std::vector;
-
-
-string gu_getRealPath(const string& path)
+namespace giada
+{
+namespace u
+{
+namespace string
 {
-	string out = "";
-
-#if defined(G_OS_LINUX) || defined(G_OS_MAC)
-
-	char *buf = realpath(path.c_str(), nullptr);
-
-#else // Windows
-
-	char *buf = _fullpath(nullptr, path.c_str(), PATH_MAX);
-
-#endif
-
-	if (buf) {
-		out = buf;
-		free(buf);
-	}
-	return out;
-}
-
-
-/* -------------------------------------------------------------------------- */
-
-
 /* TODO - use std::to_string() */
 
-string gu_fToString(float f, int precision)
+std::string fToString(float f, int precision)
 {
 	std::stringstream out;
 	out << std::fixed << std::setprecision(precision) << f;
 	return out.str();
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
-string gu_trim(const string& s)
+std::string trim(const std::string& s)
 {
 	std::size_t first = s.find_first_not_of(" \n\t");
 	std::size_t last  = s.find_last_not_of(" \n\t");
-	return s.substr(first, last-first+1);
+	return s.substr(first, last - first + 1);
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
-string gu_replace(string in, const string& search, const string& replace)
+std::string replace(std::string in, const std::string& search, const std::string& replace)
 {
-	size_t pos = 0;
-	while ((pos = in.find(search, pos)) != string::npos) {
+	std::size_t pos = 0;
+	while ((pos = in.find(search, pos)) != std::string::npos)
+	{
 		in.replace(pos, search.length(), replace);
 		pos += replace.length();
 	}
 	return in;
 }
 
-
 /* -------------------------------------------------------------------------- */
 
-
-std::string gu_format(const char* format, ...)
+std::string format(const char* format, ...)
 {
 	va_list args;
 
-	/* Compute the size of the new expanded string (i.e. with replacement taken
+	/* Compute the size of the new expanded std::string (i.e. with replacement taken
 	into account). */
 
-	size_t size = vsnprintf(nullptr, 0, format, args);
+	va_start(args, format);
+	std::size_t size = vsnprintf(nullptr, 0, format, args) + 1;
+	va_end(args);
 
-	/* Create a new temporary char array to hold the new expanded string. */
+	/* Create a new temporary char array to hold the new expanded std::string. */
 
 	std::unique_ptr<char[]> tmp(new char[size]);
 
-	/* Fill the temporary string with the formatted data. */
+	/* Fill the temporary std::string with the formatted data. */
 
-  va_start(args, format);
+	va_start(args, format);
 	vsprintf(tmp.get(), format, args);
-  va_end(args);
-  
- 	return string(tmp.get(), tmp.get() + size - 1);	
-}
+	va_end(args);
 
+	return std::string(tmp.get(), tmp.get() + size - 1);
+}
 
 /* -------------------------------------------------------------------------- */
 
-
-void gu_split(string in, string sep, vector<string>* v)
+std::vector<std::string> split(std::string in, std::string sep)
 {
-	string full  = in;
-	string token = "";
-	size_t curr = 0;
-	size_t next = -1;
-	do {
+	std::vector<std::string> out;
+	std::string              full  = in;
+	std::string              token = "";
+	std::size_t              curr  = 0;
+	std::size_t              next  = -1;
+	do
+	{
 		curr  = next + 1;
 		next  = full.find_first_of(sep, curr);
 		token = full.substr(curr, next - curr);
 		if (token != "")
-			v->push_back(token);
-	}
-	while (next != string::npos);
+			out.push_back(token);
+	} while (next != std::string::npos);
+	return out;
 }
+
+} // namespace string
+} // namespace u
+} // namespace giada
