@@ -6,7 +6,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2022 Giovanni A. Zuliani | Monocasual Laboratories
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -26,40 +26,43 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef G_UTILS_STRING_H
 #define G_UTILS_STRING_H
 
-
+#include <sstream>
 #include <string>
 #include <vector>
-#include <sstream>
-#include "../core/const.h"
-
 
+namespace giada
+{
+namespace u
+{
+namespace string
+{
 template <typename T>
-std::string gu_iToString(T t, bool hex=false)
+std::string iToString(T t, bool hex = false)
 {
 	std::stringstream out;
 	if (hex)
 		out << std::hex << std::uppercase << t;
 	else
 		out << t;
-	return out.str();	
+	return out.str();
 }
 
-std::string gu_getRealPath(const std::string& path);
+std::string replace(std::string in, const std::string& search,
+    const std::string& replace);
 
-std::string gu_replace(std::string in, const std::string& search,
-  const std::string& replace);
+std::string trim(const std::string& s);
 
-std::string gu_trim(const std::string& s);
+std::vector<std::string> split(std::string in, std::string sep);
 
-void gu_split(std::string in, std::string sep, std::vector<std::string>* v);
+std::string fToString(float f, int precision);
 
-std::string gu_fToString(float f, int precision);
-
-std::string gu_format(const char* format, ...);
+std::string format(const char* format, ...);
 
+} // namespace string
+} // namespace u
+} // namespace giada
 
 #endif
