@@ -6,7 +6,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2022 Giovanni A. Zuliani | Monocasual Laboratories
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -26,27 +26,20 @@
  *
  * -------------------------------------------------------------------------- */
 
-
-#include "../core/const.h"
-#ifndef G_OS_MAC
-	#include <chrono>
-	#include <thread>
-#else
-	#include <unistd.h>
-#endif
 #include "time.h"
+#include <chrono>
+#include <thread>
 
-
-namespace giada {
-namespace u     {
-namespace time 
+namespace giada
+{
+namespace u
+{
+namespace time
 {
 void sleep(int millisecs)
 {
-#ifndef G_OS_MAC
 	std::this_thread::sleep_for(std::chrono::milliseconds(millisecs));
-#else
-	usleep(millisecs * 1000);
-#endif
 }
-}}};  // giada::u::time::
+} // namespace time
+} // namespace u
+} // namespace giada
