@@ -6,7 +6,7 @@
  *
  * -----------------------------------------------------------------------------
  *
- * Copyright (C) 2010-2018 Giovanni A. Zuliani | Monocasual
+ * Copyright (C) 2010-2022 Giovanni A. Zuliani | Monocasual Laboratories
  *
  * This file is part of Giada - Your Hardcore Loopmachine.
  *
@@ -26,17 +26,18 @@
  *
  * -------------------------------------------------------------------------- */
 
-
 #ifndef G_UTILS_TIME_H
 #define G_UTILS_TIME_H
 
-
-namespace giada {
-namespace u     {
-namespace time 
+namespace giada
+{
+namespace u
+{
+namespace time
 {
 void sleep(int millisecs);
-}}};
-
+}
+} // namespace u
+} // namespace giada
 
 #endif
\ No newline at end of file
